@@ -37,6 +37,7 @@ import (
 	"github.com/blacktop/ipsw/internal/download"
 	"github.com/blacktop/ipsw/internal/utils"
 	"github.com/blacktop/ipsw/pkg/dyld"
+	"github.com/blacktop/ipsw/pkg/ota/types"
 	"github.com/dustin/go-humanize"
 	"github.com/fatih/color"
 	semver "github.com/hashicorp/go-version"
@@ -94,6 +95,7 @@ func init() {
 	downloadOtaCmd.Flags().Bool("driver-kit", false, "Extract DriverKit dyld_shared_cache(s) from remote OTA zip")
 	downloadOtaCmd.Flags().String("pattern", "", "Download remote files that match regex")
 	downloadOtaCmd.Flags().BoolP("flat", "f", false, "Do NOT preserve directory structure when downloading with --pattern")
+	downloadOtaCmd.Flags().Bool("fcs-keys", false, "Get AEA decryption keys as JSON database from OTA metadata")
 	downloadOtaCmd.Flags().Bool("info", false, "Show all the latest OTAs available")
 	downloadOtaCmd.Flags().StringP("output", "o", "", "Folder to download files to")
 	downloadOtaCmd.MarkFlagDirname("output")
@@ -130,6 +132,7 @@ func init() {
 	viper.BindPFlag("download.ota.kernel", downloadOtaCmd.Flags().Lookup("kernel"))
 	viper.BindPFlag("download.ota.pattern", downloadOtaCmd.Flags().Lookup("pattern"))
 	viper.BindPFlag("download.ota.flat", downloadOtaCmd.Flags().Lookup("flat"))
+	viper.BindPFlag("download.ota.fcs-keys", downloadOtaCmd.Flags().Lookup("fcs-keys"))
 	viper.BindPFlag("download.ota.info", downloadOtaCmd.Flags().Lookup("info"))
 	viper.BindPFlag("download.ota.output", downloadOtaCmd.Flags().Lookup("output"))
 	viper.BindPFlag("download.ota.show-latest-version", downloadOtaCmd.Flags().Lookup("show-latest-version"))
@@ -153,6 +156,9 @@ var downloadOtaCmd = &cobra.Command{
 
 		# Download Xcode Simulator Runtime OTAs
 		❯ ipsw download ota --platform ios --sim --build "22F77"
+
+		# Get AEA decryption keys as JSON from latest iOS OTAs
+		❯ ipsw download ota --platform ios --latest --fcs-keys
 	`),
 	SilenceErrors: true,
 	RunE: func(cmd *cobra.Command, args []string) error {
@@ -187,6 +193,7 @@ var downloadOtaCmd = &cobra.Command{
 		remoteKernel := viper.GetBool("download.ota.kernel")
 		remotePattern := viper.GetString("download.ota.pattern")
 		flat := viper.GetBool("download.ota.flat")
+		fcsKeys := viper.GetBool("download.ota.fcs-keys")
 		otaInfo := viper.GetBool("download.ota.info")
 		output := viper.GetString("download.ota.output")
 		showLatestVersion := viper.GetBool("download.ota.show-latest-version")
@@ -204,26 +211,26 @@ var downloadOtaCmd = &cobra.Command{
 				}
 			}
 		}
-		if len(platform) == 0 {
+		if platform == "" {
 			return fmt.Errorf("you must supply a valid --platform flag. Choices are: ios, watchos, tvos, audioos, visionos || accessory, macos, recovery")
 		} else {
 			if !utils.StrSliceHas([]string{"ios", "macos", "recovery", "watchos", "tvos", "audioos", "accessory", "visionos"}, platform) {
 				return fmt.Errorf("valid --platform flag choices are: ios, watchos, tvos, audioos, visionos || accessory, macos, recovery")
 			}
 		}
-		if (showLatestVersion || showLatestBuild) && len(device) == 0 {
+		if (showLatestVersion || showLatestBuild) && device == "" {
 			return fmt.Errorf("you must supply a --device when using --show-latest-version or --show-latest-build")
 		}
-		if len(version) == 0 {
+		if version == "" {
 			version = "0"
 		}
-		if getRSR && len(build) == 0 {
+		if getRSR && build == "" {
 			return fmt.Errorf("for now you will need to supply a --build number when using --rsr")
 		}
-		if viper.GetBool("download.ota.delta") && (len(build) == 0 || len(version) == 0) {
+		if viper.GetBool("download.ota.delta") && (build == "" || version == "") {
 			return fmt.Errorf("for now you will need to supply a --version AND --build number when using --delta")
 		}
-		if len(build) == 0 {
+		if build == "" {
 			build = "0"
 		}
 
@@ -341,6 +348,98 @@ var downloadOtaCmd = &cobra.Command{
 			return fmt.Errorf("no OTA found")
 		}
 
+		if fcsKeys {
+			var fcsKeyEntries []types.AEAKeyEntry
+			for _, o := range otas {
+				if len(o.ArchiveDecryptionKey) > 0 {
+					url := o.BaseURL + o.RelativePath
+					filename := filepath.Base(o.RelativePath)
+					fcsKeyEntries = append(fcsKeyEntries, types.AEAKeyEntry{
+						OS:              o.ProductSystemName,
+						Version:         strings.TrimPrefix(o.OSVersion, "9.9."),
+						Build:           o.Build,
+						Devices:         o.SupportedDevices,
+						Models:          o.SupportedDeviceModels,
+						Key:             o.ArchiveDecryptionKey,
+						DocumentationID: o.DocumentationID,
+						URL:             url,
+						Filename:        filename,
+						Size:            uint64(o.UnarchivedSize),
+					})
+				}
+			}
+			if len(fcsKeyEntries) == 0 {
+				log.Warn("No AEA encrypted OTAs found with decryption keys")
+				return nil
+			}
+
+			outFile := filepath.Join(destPath, "ota_fcs_keys.json")
+
+			// Read existing entries if file exists
+			var existingEntries []types.AEAKeyEntry
+			if data, err := os.ReadFile(outFile); err == nil {
+				if err := json.Unmarshal(data, &existingEntries); err != nil {
+					log.WithError(err).Warn("Failed to parse existing FCS keys JSON, will overwrite")
+				}
+			}
+
+			// Merge new entries with existing, using filename as unique key
+			entryMap := make(map[string]types.AEAKeyEntry)
+			for _, entry := range existingEntries {
+				entryMap[entry.Filename] = entry
+			}
+			// Track actually new entries
+			newCount := 0
+			updatedCount := 0
+			for _, entry := range fcsKeyEntries {
+				if _, exists := entryMap[entry.Filename]; exists {
+					updatedCount++
+				} else {
+					newCount++
+				}
+				entryMap[entry.Filename] = entry
+			}
+
+			// Extract keys and sort them for deterministic iteration
+			keys := make([]string, 0, len(entryMap))
+			for k := range entryMap {
+				keys = append(keys, k)
+			}
+			sort.Strings(keys)
+
+			// Build slice in sorted key order, then sort by version/build
+			mergedEntries := make([]types.AEAKeyEntry, 0, len(entryMap))
+			for _, k := range keys {
+				mergedEntries = append(mergedEntries, entryMap[k])
+			}
+			sort.Slice(mergedEntries, func(i, j int) bool {
+				if mergedEntries[i].Version != mergedEntries[j].Version {
+					return mergedEntries[i].Version > mergedEntries[j].Version
+				}
+				return mergedEntries[i].Build > mergedEntries[j].Build
+			})
+
+			dat, err := json.MarshalIndent(mergedEntries, "", "  ")
+			if err != nil {
+				return fmt.Errorf("failed to marshal FCS keys to JSON: %v", err)
+			}
+			if err := os.WriteFile(outFile, dat, 0644); err != nil {
+				return fmt.Errorf("failed to write FCS keys JSON: %v", err)
+			}
+
+			if newCount > 0 && updatedCount > 0 {
+				log.Infof("Added %d new, updated %d existing entries in %s (total: %d)", newCount, updatedCount, outFile, len(mergedEntries))
+			} else if newCount > 0 {
+				log.Infof("Added %d new entries to %s (total: %d)", newCount, outFile, len(mergedEntries))
+			} else if updatedCount > 0 {
+				log.Infof("Updated %d existing entries in %s (total: %d)", updatedCount, outFile, len(mergedEntries))
+			} else {
+				log.Infof("No changes to %s (total: %d)", outFile, len(mergedEntries))
+			}
+
+			return nil
+		}
+
 		if viper.GetBool("download.ota.urls") || viper.GetBool("download.ota.json") {
 			if viper.GetBool("download.ota.json") {
 				dat, err := json.Marshal(otas)
