@@ -30,7 +30,7 @@ import (
 // backupEraseCmd represents the erase command
 var backupEraseCmd = &cobra.Command{
 	Use:   "erase",
-	Short: "A brief description of your command",
+	Short: "Erase a backup",
 	Long: `A longer description that spans multiple lines and likely contains examples
 and usage of using your command. For example:
 
