@@ -25,10 +25,8 @@ import (
 	"encoding/json"
 	"fmt"
 
-	"github.com/apex/log"
 	"github.com/blacktop/ipsw/internal/utils"
 	"github.com/blacktop/ipsw/pkg/usb/diagnostics"
-	"github.com/fatih/color"
 	"github.com/spf13/cobra"
 	"github.com/spf13/viper"
 )
@@ -37,23 +35,18 @@ func init() {
 	DiagCmd.AddCommand(idevDiagMobileGestaltCmd)
 	idevDiagMobileGestaltCmd.Flags().StringSliceP("keys", "k", []string{}, "Keys to retrieve (can be csv)")
 	idevDiagMobileGestaltCmd.MarkFlagRequired("keys")
+	viper.BindPFlag("idev.diag.mg.keys", idevDiagMobileGestaltCmd.Flags().Lookup("keys"))
 }
 
 // idevDiagMobileGestaltCmd represents the mg command
 var idevDiagMobileGestaltCmd = &cobra.Command{
 	Use:           "mg",
 	Short:         "Query MobileGestalt",
-	SilenceUsage:  true,
 	SilenceErrors: true,
 	RunE: func(cmd *cobra.Command, args []string) error {
 
-		if viper.GetBool("verbose") {
-			log.SetLevel(log.DebugLevel)
-		}
-		color.NoColor = viper.GetBool("no-color")
-
-		udid, _ := cmd.Flags().GetString("udid")
-		keys, _ := cmd.Flags().GetStringSlice("keys")
+		udid := viper.GetString("idev.udid")
+		keys := viper.GetStringSlice("idev.diag.mg.keys")
 
 		if len(udid) == 0 {
 			dev, err := utils.PickDevice()
