@@ -22,10 +22,7 @@ THE SOFTWARE.
 package idev
 
 import (
-	"github.com/apex/log"
-	"github.com/fatih/color"
 	"github.com/spf13/cobra"
-	"github.com/spf13/viper"
 )
 
 func init() {
@@ -37,16 +34,10 @@ var restoreRamdiskCmd = &cobra.Command{
 	Use:           "ramdisk",
 	Short:         "Enter ramdisk",
 	Args:          cobra.MaximumNArgs(2),
-	SilenceUsage:  true,
 	SilenceErrors: true,
 	Hidden:        true,
 	RunE: func(cmd *cobra.Command, args []string) error {
 
-		if viper.GetBool("verbose") {
-			log.SetLevel(log.DebugLevel)
-		}
-		color.NoColor = viper.GetBool("no-color")
-
 		panic("not implemented") // TODO: implement
 
 		return nil
