@@ -34,7 +34,6 @@ import (
 	"github.com/blacktop/ipsw/internal/utils"
 	"github.com/blacktop/ipsw/pkg/ctf"
 	"github.com/blacktop/ipsw/pkg/kernelcache"
-	"github.com/fatih/color"
 	"github.com/spf13/cobra"
 	"github.com/spf13/viper"
 )
@@ -59,18 +58,12 @@ var ctfdumpCmd = &cobra.Command{
 	Aliases:       []string{"c", "ctf"},
 	Short:         "Dump CTF info",
 	Args:          cobra.MinimumNArgs(1),
-	SilenceUsage:  true,
 	SilenceErrors: true,
 	RunE: func(cmd *cobra.Command, args []string) error {
 
 		var err error
 		var m *macho.File
 
-		if viper.GetBool("verbose") {
-			log.SetLevel(log.DebugLevel)
-		}
-		color.NoColor = viper.GetBool("no-color")
-
 		// flags
 		selectedArch := viper.GetString("kernel.ctfdump.arch")
 		prettyJSON := viper.GetBool("kernel.ctfdump.pretty")
